@@ -86,11 +86,12 @@ class ClientAuthMethod(AuthenticationMethod):
         return toUnicode(data)
 
     def post(self, url, postParameters=None, urlParameters=None):
+        """
+        Convenience method for requesting to google with proper cookies/params.
+        """
         if urlParameters:
-            getString = self.getParameters(urlParameters)
-            req = urllib2.Request(url + "?" + getString)
-        else:
-            req = urllib2.Request(url)
+            url = url + "?" + self.getParameters(urlParameters)
+        req = urllib2.Request(url)
         req.add_header('Authorization','GoogleLogin auth=%s' % self.auth_token)
         postString = self.postParameters(postParameters)
         r = urllib2.urlopen(req, data=postString)
@@ -227,6 +228,9 @@ class OAuthMethod(AuthenticationMethod):
             raise IOError("No authorized client available.")
 
     def post(self, url, postParameters=None, urlParameters=None):
+        """
+        Convenience method for requesting to google with proper cookies/params.
+        """
         if self.authorized_client:
             if urlParameters:
                 getString = self.getParameters(urlParameters)
@@ -279,6 +283,8 @@ class OAuth2Method(AuthenticationMethod):
         '''
         Get action to prevent XSRF attacks
         http://code.google.com/p/google-reader-api/wiki/ActionToken
+
+        TODO: mask token expiring? handle regenerating?
         '''
         self.action_token = self.get(ReaderUrl.ACTION_TOKEN_URL)
 
@@ -311,6 +317,9 @@ class OAuth2Method(AuthenticationMethod):
         self.access_token = access_token
 
     def get(self, url, parameters=None):
+        """
+        Convenience method for requesting to google with proper cookies/params.
+        """
         if not self.access_token:
             raise IOError("No authorized client available.")
         if parameters is None:
@@ -323,17 +332,24 @@ class OAuth2Method(AuthenticationMethod):
         except (ValueError, KeyError, IOError) as e:
             return None
 
-    def post(self, url, postParameters=None, urlParameters={}):
+    def post(self, url, postParameters=None, urlParameters=None):
+        """
+        Convenience method for requesting to google with proper cookies/params.
+        """
         if not self.access_token:
             raise IOError("No authorized client available.")
-        urlParameters.update({'access_token': self.access_token, 'alt': 'json'})
-        getString = self.getParameters(urlParameters)
-        request = urllib2.Request(url + '?' + self.getParameters(parameters))
+        if not self.action_token:
+            raise IOError("Need to generate action token.")
+        if urlParameters is None:
+            urlParameters = {}
+        headers = {'Authorization': 'Bearer ' + self.access_token}
+        postParameters.update({'T':self.action_token})
         postString = self.postParameters(postParameters)
+        request = urllib2.Request(url + '?' + self.getParameters(urlParameters), data=postString, headers=headers)
         try:
-            response = urllib2.urlopen(request, data=postString)
-            toUnicode(response.read())
-        except (ValueError, KeyError, IOError):
+            response = urllib2.urlopen(request)
+            return toUnicode(response.read())
+        except (ValueError, KeyError, IOError) as e:
             return None
 
 class GAPDecoratorAuthMethod(AuthenticationMethod):
